==> jc-1.4.0.tar.gz: java/awt/event/ActionEvent.h <==
// public class java.awt.event.ActionEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class c3b9a5f8af0dc229 java_awt_event_ActionEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_ActionEvent_H_
#define _JC_java_awt_event_ActionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ActionEvent$sub_refs	_jc_java_awt_event_ActionEvent$sub_refs;
typedef struct _jc_java_awt_event_ActionEvent$sub_nonrefs	_jc_java_awt_event_ActionEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ActionEvent$refs	_jc_java_awt_event_ActionEvent$refs;
typedef struct _jc_java_awt_event_ActionEvent$nonrefs	_jc_java_awt_event_ActionEvent$nonrefs;
typedef struct _jc_java_awt_event_ActionEvent$object	_jc_java_awt_event_ActionEvent$object;

typedef struct _jc_java_awt_event_ActionEvent$fields_struct	_jc_java_awt_event_ActionEvent$fields_struct;
typedef const struct _jc_java_awt_event_ActionEvent$vmethods	_jc_java_awt_event_ActionEvent$vmethods;
typedef const struct _jc_java_awt_event_ActionEvent$vtable	_jc_java_awt_event_ActionEvent$vtable;
typedef const struct _jc_java_awt_event_ActionEvent$vtype	_jc_java_awt_event_ActionEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ActionEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ACTION__5fFIRST;
	jint	ACTION__5fLAST;
	jint	ACTION__5fPERFORMED;
	jint	ALT__5fMASK;
	jint	CTRL__5fMASK;
	jint	META__5fMASK;
	jint	SHIFT__5fMASK;
};
extern _jc_java_awt_event_ActionEvent$fields_struct _jc_java_awt_event_ActionEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ActionEvent$method$_init$36888fc4c27a8412(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_String$object *);
extern void _jc_java_awt_event_ActionEvent$method$_init$ad5846475270be37(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_String$object *, jint);
extern void _jc_java_awt_event_ActionEvent$method$_init$2ce2f9a314ce663a(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_String$object *, jlong, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ActionEvent$method$getActionCommand$f3e612a7646358e4(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);
extern jint _jc_java_awt_event_ActionEvent$method$getModifiers$d9bdcb51d9f4fabc(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);
extern jlong _jc_java_awt_event_ActionEvent$method$getWhen$3d8a46a7284dd8d9(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ActionEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$getActionCommand$f3e612a7646358e4;
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$getModifiers$d9bdcb51d9f4fabc;
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$getWhen$3d8a46a7284dd8d9;
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ActionEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getActionCommand$f3e612a7646358e4)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);
	jint	(*getModifiers$d9bdcb51d9f4fabc)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);
	jlong	(*getWhen$3d8a46a7284dd8d9)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_java_awt_event_ActionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ActionEvent$vmethods	java_awt_event_ActionEvent;
};

// Vtype
struct _jc_java_awt_event_ActionEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ActionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ActionEvent$sub_refs {
	struct _jc_java_lang_String$object	*actionCommand;
};

// Reference instance fields (object)
struct _jc_java_awt_event_ActionEvent$refs {
    _jc_java_awt_event_ActionEvent$sub_refs	java_awt_event_ActionEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ActionEvent$sub_nonrefs {
	jint	modifiers;
	jlong	when;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ActionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ActionEvent$sub_nonrefs	java_awt_event_ActionEvent;
};

// Object instance structure
struct _jc_java_awt_event_ActionEvent$object {
	_jc_java_awt_event_ActionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ActionEvent$vtype	*vtype;
	_jc_java_awt_event_ActionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ActionEvent$vtype _jc_java_awt_event_ActionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ActionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ActionEvent$class_object;

#endif	/* _JC_java_awt_event_ActionEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/ActionEvent.h <==
// public class java.awt.event.ActionEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class c3b9a5f8af0dc229 java_awt_event_ActionEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_ActionEvent_H_
#define _JC_java_awt_event_ActionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_ActionEvent$sub_refs	_jc_java_awt_event_ActionEvent$sub_refs;
typedef struct _jc_java_awt_event_ActionEvent$sub_nonrefs	_jc_java_awt_event_ActionEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_ActionEvent$refs	_jc_java_awt_event_ActionEvent$refs;
typedef struct _jc_java_awt_event_ActionEvent$nonrefs	_jc_java_awt_event_ActionEvent$nonrefs;
typedef struct _jc_java_awt_event_ActionEvent$object	_jc_java_awt_event_ActionEvent$object;

typedef struct _jc_java_awt_event_ActionEvent$fields_struct	_jc_java_awt_event_ActionEvent$fields_struct;
typedef const struct _jc_java_awt_event_ActionEvent$vmethods	_jc_java_awt_event_ActionEvent$vmethods;
typedef const struct _jc_java_awt_event_ActionEvent$vtable	_jc_java_awt_event_ActionEvent$vtable;
typedef const struct _jc_java_awt_event_ActionEvent$vtype	_jc_java_awt_event_ActionEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_ActionEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ACTION__5fFIRST;
	jint	ACTION__5fLAST;
	jint	ACTION__5fPERFORMED;
	jint	ALT__5fMASK;
	jint	CTRL__5fMASK;
	jint	META__5fMASK;
	jint	SHIFT__5fMASK;
};
extern _jc_java_awt_event_ActionEvent$fields_struct _jc_java_awt_event_ActionEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_ActionEvent$method$_init$36888fc4c27a8412(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_ActionEvent$method$_init$ad5846475270be37(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_ActionEvent$method$_init$2ce2f9a314ce663a(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_String$object *, jlong, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ActionEvent$method$getActionCommand$f3e612a7646358e4(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_ActionEvent$method$getModifiers$d9bdcb51d9f4fabc(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_awt_event_ActionEvent$method$getWhen$3d8a46a7284dd8d9(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_ActionEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$getActionCommand$f3e612a7646358e4;
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$getModifiers$d9bdcb51d9f4fabc;
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$getWhen$3d8a46a7284dd8d9;
extern _jc_method _jc_java_awt_event_ActionEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_ActionEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getActionCommand$f3e612a7646358e4)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	jint	(*getModifiers$d9bdcb51d9f4fabc)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	jlong	(*getWhen$3d8a46a7284dd8d9)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_ActionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ActionEvent$vmethods	java_awt_event_ActionEvent;
};

// Vtype
struct _jc_java_awt_event_ActionEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_ActionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_ActionEvent$sub_refs {
	struct _jc_java_lang_String$object	*actionCommand;
};

// Reference instance fields (object)
struct _jc_java_awt_event_ActionEvent$refs {
    _jc_java_awt_event_ActionEvent$sub_refs	java_awt_event_ActionEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_ActionEvent$sub_nonrefs {
	jint	modifiers;
	jlong	when;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_ActionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ActionEvent$sub_nonrefs	java_awt_event_ActionEvent;
};

// Object instance structure
struct _jc_java_awt_event_ActionEvent$object {
	_jc_java_awt_event_ActionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_ActionEvent$vtype	*vtype;
	_jc_java_awt_event_ActionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_ActionEvent$vtype _jc_java_awt_event_ActionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_ActionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_ActionEvent$class_object;

#endif	/* _JC_java_awt_event_ActionEvent_H_ */
